summaryrefslogtreecommitdiffstats
path: root/os-plugins
diff options
context:
space:
mode:
authorMichael Janczyk2009-02-18 23:25:03 +0100
committerMichael Janczyk2009-02-18 23:25:03 +0100
commit4dd0c5a410c977cf5ce00bec0edc2f54789c4d76 (patch)
tree119ccc9b60850cf35acef703d7100c19f52cca33 /os-plugins
parentMore on the new virtualization starter framework. (diff)
downloadcore-4dd0c5a410c977cf5ce00bec0edc2f54789c4d76.tar.gz
core-4dd0c5a410c977cf5ce00bec0edc2f54789c4d76.tar.xz
core-4dd0c5a410c977cf5ce00bec0edc2f54789c4d76.zip
bugfix splashy + now /w splashy.shutdown ;)
git-svn-id: http://svn.openslx.org/svn/openslx/openslx/trunk@2610 95ad53e4-c205-0410-b2fa-d234c58c8868
Diffstat (limited to 'os-plugins')
-rw-r--r--os-plugins/plugins/bootsplash/XX_bootsplash.sh38
-rw-r--r--os-plugins/plugins/bootsplash/init-hooks/05-have-kernelvars/bootsplash.sh4
2 files changed, 31 insertions, 11 deletions
diff --git a/os-plugins/plugins/bootsplash/XX_bootsplash.sh b/os-plugins/plugins/bootsplash/XX_bootsplash.sh
index 9a36c08f..44fffe7c 100644
--- a/os-plugins/plugins/bootsplash/XX_bootsplash.sh
+++ b/os-plugins/plugins/bootsplash/XX_bootsplash.sh
@@ -1,5 +1,5 @@
# Copyright (c) 2007..2008 - RZ Uni Freiburg
-# Copyright (c) 2008 - OpenSLX GmbH
+# Copyright (c) 2008 - 2009 OpenSLX GmbH
#
# This program/file is free software distributed under the GPL version 2.
# See http://openslx.org/COPYING
@@ -19,14 +19,34 @@ if [ -e /initramfs/plugin-conf/bootsplash.conf ]; then
if [ $bootsplash_active -ne 0 ]; then
if [ ${no_bootsplash} -eq 0 ]; then
# create a runlevelscript that will stop splashy before the start of KDM
- d_mkrlscript init splashy.stop "Stopping Splashy ..."
- echo -e "\tLD_LIBRARY_PATH=/opt/openslx/uclib-rootfs/lib/
- /opt/openslx/plugin-repo/bootsplash/bin/splashy_update exit \
- 2>/dev/null \
- \n\ttype killall >/dev/null 2>&1 && killall -9 splashy \
- \n\trm -f /etc/init.d/splashy.stop 2>/dev/null" \
- >>/mnt/etc/init.d/splashy.stop
- d_mkrlscript close splashy.stop ""
+ d_mkrlscript init splashy.boot ""
+ echo -e "\tLD_LIBRARY_PATH=/opt/openslx/uclib-rootfs/lib/ \
+ /opt/openslx/plugin-repo/bootsplash/bin/splashy_update \
+ exit 2>/dev/null \
+ \n\ttype killall >/dev/null 2>&1 && killall -9 splashy" \
+ >>/mnt/etc/init.d/splashy.boot
+ d_mkrlscript close splashy.boot ""
+ # create a runlevelscript that will start splashy on halt/reboot
+ echo '#!/bin/sh' >>/mnt/etc/init.d/splashy.halt
+ echo -e ". /etc/rc.status \
+ \n. /etc/sysconfig/logfile \
+ \nrc_reset \
+ \ncase \"\$1\" in \
+ \n\tstart) \
+ \n\t\t;; \
+ \n\tstop) \
+ \n\t\t/opt/openslx/plugin-repo/bootsplash/bin/splashy shutdown \
+ \n\t\tsleep 1 \
+ \n\t\tLD_LIBRARY_PATH=/opt/openslx/uclib-rootfs/lib/ \
+ /opt/openslx/plugin-repo/bootsplash/bin/splashy_update \
+ \"progress 100\" 2>/dev/null \
+ \n\t\t;; \
+ \nesac \
+ \nrc_exit" \
+ >>/mnt/etc/init.d/splashy.halt
+ chmod 744 /mnt/etc/init.d/splashy.halt
+ cp -a /etc/splashy /mnt/etc/
+ rllinker "splashy.halt" 1 1
fi
fi
fi
diff --git a/os-plugins/plugins/bootsplash/init-hooks/05-have-kernelvars/bootsplash.sh b/os-plugins/plugins/bootsplash/init-hooks/05-have-kernelvars/bootsplash.sh
index e69900ce..24bdcba4 100644
--- a/os-plugins/plugins/bootsplash/init-hooks/05-have-kernelvars/bootsplash.sh
+++ b/os-plugins/plugins/bootsplash/init-hooks/05-have-kernelvars/bootsplash.sh
@@ -12,6 +12,6 @@ fi
if [ ${no_bootsplash} -eq 0 ]; then
/bin/splashy boot 2>/dev/null
- # add splashy.stop runlevel script
- export D_SPLASHY=splashy.stop
+ # add splashy.boot runlevel script
+ export D_SPLASHY=splashy.boot
fi